@@ -10,7 +10,7 @@
 */
 require_once( 'FrameworkClassLoader.class.php' );
 
-class charcoal_ClassLoader
+class ClassLoader
 {
 	var $_loaders;
 
@@ -29,7 +29,7 @@ class charcoal_ClassLoader
 	{
 		static $singleton_;
 		if ( $singleton_ == null ){
-			$singleton_ = new charcoal_ClassLoader();
+			$singleton_ = new ClassLoader();
 		}
 		return $singleton_;
 	}
@@ -37,7 +37,7 @@ class charcoal_ClassLoader
 	/*
 	 * 饹ɲ
 	 */
-	public static function addClassLoader( charcoal_IClassLoader $loader )
+	public static function addClassLoader( IClassLoader $loader )
 	{
 		// 󥹥󥹤μ
 		$ins = & self::getInstance();
@@ -51,7 +51,7 @@ class charcoal_ClassLoader
 	public static function loadClass( $class_name )
 	{
 		// ե졼饹
-		if ( charcoal_FrameworkClassLoader::loadClass( $class_name ) ){
+		if ( FrameworkClassLoader::loadClass( $class_name ) ){
 			return TRUE;
 		}
 
@@ -60,11 +60,12 @@ class charcoal_ClassLoader
 
 		// 饹֤˸ƤӽФ
 		foreach( $ins->_loaders as $loader ){
-			if ( $loader->loadClass($class_name) ){
+			if ( $loader->loadClass(s($class_name)) ){
 				return TRUE;
 			}
 		}
 
 		return FALSE;
 	}
-}
\ No newline at end of file
+}
+return __FILE__;
\ No newline at end of file
