@@ -15,6 +15,21 @@ interface ITask extends IObject
 	 */
 	public function init( Config $config );
 
+	/**
+	 * ɾ
+	 */
+	public function getGuardConditions();
+
+	/**
+	 * ٥ȥե륿
+	 */
+	public function getEventFilters();
+
+	/**
+	 * ݥȥ
+	 */
+	public function getPostActions();
+
 	/**
 	 * ٥Ȥ
 	 */
